@@ -1,6 +1,7 @@
 
-# Port to listen to
+# Port and address to listen to
 listenport = 1881
+bind_address = "127.0.0.1"
 
 # Stick your last.fm username and password between the quotes below.
 username = "yourusername"
